@@ -41,7 +41,6 @@
 #include <QByteArray>
 #include <QDate>
 #include <QDateTime>
-#include <QDir>
 #include <QLabel>
 #include <QHeaderView>
 #include <QPushButton>
@@ -53,12 +52,15 @@
 #include <QTreeWidget>
 #include <QTreeWidgetItem>
 #include <QVBoxLayout>
+#include <QFileInfo>
 
 #include <KConfigGroup>
 #include <KGuiItem>
 #include <KRandomSequence>
 #include <KSharedConfig>
 #include <KStandardGuiItem>
+#include <KLocalizedString>
+#include <KMessageBox>
 
 #include "kgoldrunner_debug.h"
 
@@ -1712,7 +1714,7 @@ void KGrGame::checkHighScore()
     int spacing = 10;
     QVBoxLayout *	mainLayout = new QVBoxLayout (hsn);
     mainLayout->setSpacing (spacing);
-    mainLayout->setMargin (margin);
+    mainLayout->setContentsMargins(margin, margin, margin, margin);
 
     QLabel *		hsnMessage  = new QLabel (
                         i18n ("<html><b>Congratulations !!!</b><br/>"
@@ -1874,7 +1876,7 @@ void KGrGame::showHighScores()
     int spacing = 10;
     QVBoxLayout *	mainLayout = new QVBoxLayout (hs);
     mainLayout->setSpacing (spacing);
-    mainLayout->setMargin (margin);
+    mainLayout->setContentsMargins(margin, margin, margin, margin);
 
     QLabel *		hsHeader = new QLabel (i18n (
                             "<center><h2>KGoldrunner Hall of Fame</h2></center>"
